@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.207';
+our $VERSION = '0.208';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::Table - table widget with support for scrolling/paging
 
 =head1 VERSION
 
-Version 0.207
+version 0.208
 
 =head1 SYNOPSIS
 
@@ -158,9 +158,10 @@ use POSIX qw(floor);
 use Adapter::Async::OrderedList;
 use Adapter::Async::OrderedList::Array;
 
-use constant CLEAR_BEFORE_RENDER => 0;
+use constant WIDGET_PEN_FROM_STYLE => 1;
+use constant CLEAR_BEFORE_RENDER   => 0;
 use constant KEYPRESSES_FROM_STYLE => 1;
-use constant CAN_FOCUS => 1;
+use constant CAN_FOCUS             => 1;
 
 BEGIN {
 	style_definition 'base' =>
@@ -1600,4 +1601,4 @@ With thanks to the following for contribution:
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2012-2015. Licensed under the same terms as Perl itself.
